@@ -27,7 +27,6 @@
 #define GNOME_PRINT_UNSTABLE_API
 
 #include <config.h>
-#include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
@@ -320,9 +319,8 @@ gnome_print_config_get_boolean (GnomePrintConfig *config, const guchar *key, gbo
 		    !g_ascii_strcasecmp (v, "yes") ||
 		    (atoi (v) != 0)) {
 			*val = TRUE;
-			return TRUE;
-		}
-		*val = FALSE;
+		} else
+			*val = FALSE;
 		g_free (v);
 		return TRUE;
 	}
@@ -439,7 +437,7 @@ gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdou
 		g_free (v);
 		return FALSE;
 	}
-	while (*e && !isalnum (*e))
+	while (*e && !g_ascii_isalnum (*e))
 		e++;
 	if (*e != '\0') {
 		c_unit = gnome_print_unit_get_by_abbreviation (e);
@@ -557,6 +555,11 @@ gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdou
 
 	g_ascii_dtostr (c, sizeof (c), val);
 	c_abbr = g_strconcat (c, unit->abbr, NULL);
+
+#if 0
+	g_warning ("gnome_print_config_set_length %s %s", key, unit->abbr);
+#endif
+
 	result = gnome_print_config_set (config, key, c_abbr);
 	g_free (c_abbr);
 
