@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: crc32.h,v 1.2 2004/09/10 18:59:06 jody Exp $ */
+/* $Id: crc32.h,v 1.3 2005/01/04 20:10:46 jody Exp $ */
 /* @(#)crc32.h 1.6 03/01/08 SMI */
 
 /*
@@ -51,7 +51,7 @@ extern "C"{
 #endif
 
 #define crc32 stsf_crc32
-uint32 stsf_crc32(const void *ptr, size_t len);
+guint32 stsf_crc32(const void *ptr, size_t len);
 
 #ifdef __cplusplus
 }
